#!/bin/bash

# 停止 MySQL 服务
echo "停止 MySQL 服务..."
systemctl stop mysqld
if [ $? -ne 0 ]; then
    echo "停止 MySQL 服务失败，可能服务未运行。"
else
    echo "MySQL 服务已停止。"
fi

# 禁用 MySQL 开机自启
echo "禁用 MySQL 开机自启..."
systemctl disable mysqld
if [ $? -ne 0 ]; then
    echo "禁用 MySQL 开机自启失败。"
else
    echo "MySQL 开机自启已禁用。"
fi

# 查找并卸载 MySQL 相关软件包
echo "查找并卸载 MySQL 相关软件包..."
mysql_packages=$(rpm -qa | grep mysql)
mariadb_packages=$(rpm -qa | grep mariadb)

if [ -n "$mysql_packages" ]; then
    echo "发现 MySQL 相关软件包，开始卸载..."
    for package in $mysql_packages; do
        yum -y remove "$package"
    done
fi

if [ -n "$mariadb_packages" ]; then
    echo "发现 MariaDB 相关软件包，开始卸载..."
    for package in $mariadb_packages; do
        yum -y remove "$package"
    done
fi

# 删除 MySQL 的配置文件和数据目录
echo "删除 MySQL 的配置文件和数据目录..."
rm -rf /etc/my.cnf /etc/my.cnf.d /var/lib/mysql /var/log/mysqld.log
if [ $? -ne 0 ]; then
    echo "删除 MySQL 配置文件和数据目录失败，请手动检查并删除。"
else
    echo "MySQL 配置文件和数据目录已删除。"
fi

# 清理 yum 缓存
echo "清理 yum 缓存..."
yum clean all
if [ $? -ne 0 ]; then
    echo "清理 yum 缓存失败。"
else
    echo "yum 缓存已清理。"
fi

echo "MySQL 已成功卸载。"